#!/usr/bin/python
# -*- coding=utf-8 -*-

import os
import urllib2
import zipfile

__help__ = """This module will install Twitter bootstrap. If you use examples, the module will generate bootstrap-ready html files in templates directory. """


requirements = [ ]

directories = [
    "[base]",
    "[base]/[name]",
    "[base]/[name]/static",
    "[base]/[name]/static/bootstrap",
    "[base]/[name]/templates",
    "[base]/[name]/views",
]

files = [ 
    "[base]/[name]/templates/bootstrap.html",
    "[base]/[name]/views/__init__.py",
]

def install(basepath, name):
    """
        Download Install Bootstrap files 
    """
    # http://twitter.github.io/bootstrap/assets/bootstrap.zip
    
    static_files_path = os.path.join(basepath, name, "static/")
    bootstrap_file_path = os.path.join(static_files_path, "bootstrap.zip")
    
    
    remote_file = urllib2.urlopen('http://twitter.github.io/bootstrap/assets/bootstrap.zip').read()
    localfile = open(bootstrap_file_path, 'w')
    localfile.write(remote_file)
    localfile.close()
    
    current_dir = os.getcwd()
    bootstrap_zip = zipfile.ZipFile(bootstrap_file_path)
    os.chdir(static_files_path)
    for f in bootstrap_zip.namelist():
        if f.endswith('/'):
            new_directory = os.path.join(static_files_path,f)
            if not os.path.exists(new_directory):
                os.makedirs(new_directory)
        else:
            bootstrap_zip.extract(f)
    os.chdir(current_dir)
    os.remove(bootstrap_file_path)
    
    bootstrap_layout_file = open(os.path.join(basepath,name,"templates/bootstrap.html"), "w")
    bootstrap_layout_file.write("""<html>
    <head>
        <title>%s {%% block title %%}{%% endblock %%}</title>

        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
                
        <script src="//code.jquery.com/jquery.min.js"></script>
        <script src="/static/bootstrap/js/bootstrap.js"></script>
        <link href="/static/bootstrap/css/bootstrap.css" rel="stylesheet">
        <link href="/static/bootstrap/css/bootstrap-responsive.css" rel="stylesheet">
    
        <!-- Le HTML5 shim, for IE6-8 support of HTML5 elements -->
        <!--[if lt IE 9]>
          <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
        <![endif]-->
        {%% block head %%}{%% endblock %%}
    </head>
    <body>
        {%% block header %%}{%% endblock %%}
        <div class="container">
            {%% block container %%}{%% endblock %%}
            %s is powered by <a href="http://projects.setale.me/Steroids">Steroids</a>
        </div>
        {%% block footer %%}{%% endblock %%}
    </body>    
</html>""" % (name, name))
    bootstrap_layout_file.close()
    
    return
    
def install_examples(basepath, name):
    """
        Install Bootstrap Templates files. ( examples )
    """
    example_directory = os.path.join(basepath,name,"templates/examples")
    if not os.path.exists(example_directory):
        os.mkdir(example_directory)

    bootstrap_example_directory = os.path.join(example_directory, "bootstrap")
    if not os.path.exists(bootstrap_example_directory):
        os.mkdir(bootstrap_example_directory)
    
    bootstrap_example_file = open(os.path.join(bootstrap_example_directory, "homepage.html"), "w")
    bootstrap_example_file.write("""{% extends "bootstrap.html" %}

{% block container %}
<h1>Hello World!</h1>
<div class="hero-unit">
    <p class="lead">
        This is an example using Bootstrap!
    <p>
</div>
{% endblock %}
""")
    bootstrap_example_file.close()
    
    init_file = open(os.path.join(basepath,"%s/__init__.py" % name), "a")
    init_file.write("\nimport %s.views.bootstrapExample\n" % name)
    init_file.close()
    
    example_file = open(os.path.join(basepath,"%s/views/bootstrapExample.py" % name), "w")
    example_file.write("""#!/usr/bin/python
# -*- coding=utf-8 -*-
from %s import app
from %s.decorators import *
from %s.constants import *

from flask import render_template
from flask import url_for
from flask import session
from flask import abort
from flask import redirect
from flask import flash

@app.route("/bootstrap")
def bootstrapExample_homepage():
    return render_template("examples/bootstrap/homepage.html")

""" % (name, name, name))
    example_file.close()

    return


#!/usr/bin/python
# -*- coding=utf-8 -*-

import os

__help__ = """
"""


requirements = [
    "honcho"
]

directories = [ ]

files = [
    "[base]/Procfile"
]

def install(basepath, name):
    """
        Install Honcho/Foreman Module
    """
    proc_file = open(os.path.join(basepath,"Procfile"), "a")
    proc_file.write("web: python server.py\n")
    proc_file.close()
    return
    
def install_examples(basepath, name):
    """
        Install Honcho/Foreman Module examples
    """
    proc_file = open(os.path.join(basepath,"Procfile"), "a")
    proc_file.write("##Uncomment to enable:\n")
    proc_file.write("# web: python tornado.py # tornado web server\n")
    proc_file.write("# clock: python clock.py # clock / cron daemon\n")
    proc_file.close()
    return


import os
import sys

__help__ = """Google App Engine (gae)

To use Google App Engine correctly with other modules ( ex: flask ) you 
should use this command to install everything in your working directory:

  sudo pip install -U -r requirements.txt -t $PWD/modules

This command will download and install all everything gae needs into the
current directory.
"""


requirements = [
    ""
]

directories = [
    "[base]",
    "[base]/modules",
    "[base]/[name]",
    "[base]/[name]/objects"
    ]

files = [
    "[base]/app.yaml",
    "[base]/gae.py",
    ]

def install(basepath, name):
    """
        Install Tornado Module
    """
    
    gae_yaml_file = open(os.path.join(basepath,"app.yaml"), "w")
    gae_yaml_file.write("""application: %s
version: 1
runtime: python27
api_version: 1
threadsafe: yes

handlers:
- url: .*
  script: gae.py
""" % name)
    gae_yaml_file.close()

    gae_py_file = open(os.path.join(basepath,"gae.py"), "w")
    gae_py_file.write("""from google.appengine.ext.webapp.util import run_wsgi_app

import os
import sys
sys.path.append(os.path.join(os.getcwd(),"modules"))

from %s import app
run_wsgi_app(app)
""" % name)
    gae_py_file.close()

    return
    
def install_examples(basepath, name):
    """
        Install Tornado Module with example files
    """
    gae_object_example = open(os.path.join(basepath,name,"objects/Example.py"), "w")
    gae_object_example.write("""#!/usr/bin/env python
# -*- coding=utf-8 -*-

from google.appengine.ext import db

class Example(db.Model):
    \"""
        Location Object 
    \"""
    astring = db.StringProperty()
    adescription = db.TextProperty()
    atype = db.CategoryProperty()

    apoint = db.GeoPtProperty()
    anaddress = db.PostalAddressProperty()
    somekeywords = db.StringListProperty()

    afloat = db.FloatProperty()

    arating = db.RatingProperty()
    #areference = db.ReferenceProperty(Example)

""" )
    gae_object_example.close()

    return


#!/usr/bin/python
# -*- coding=utf-8 -*-

import os

__help__ = """MongoDB (from "humongous") is an open-source document database, and the leading NoSQL database, written in C++.

This module provide integration with pymongo to save objects inside a MongoDB instance."""


requirements = [
    "pymongo"
]

directories = [
    "[base]/[name]",
    "[base]/[name]/objects",
]

files = [
    "[base]/settings.py",
    "[base]/[name]/__init__.py",
    "[base]/[name]/objects/__init__.py",
    "[base]/[name]/objects/Master.py",
]

def install(basepath, name):
    """
        Install MongoDB Module
    """
    
    objectMaster_file = open(os.path.join(basepath,"%s/objects/Master.py" % name), "w")
    objectMaster_file.write("""#!/usr/bin/env python
# -*- coding=utf-8 -*-

from pymongo import Connection
from pymongo.objectid import ObjectId
import json


class Master(object):
    def __init__(self):
        self.id = None

        self._connection = None
        self._database = None
        self._collection = str()

    def connect(self, host, port, dbname, collection=None, username=None, password=None):
        \"""
            This function will connect the object to the database. 
        \"""

        self._connection =  Connection(host, port)
        self._database = self._connection[dbname]
        if username and password:
            self._database.authenticate(username,password)

    def save(self):
        \"""
            Save the object in the database and overwrite if it already exists.
        \"""
        
        dictionary = self.__dict__()
        
        existing_dictionary = self._database[self._collection].find_one( { "_id" : ObjectId(self.id) } )
        if existing_dictionary:
            existing_dictionary.update(dictionary)
        else:
            existing_dictionary = dictionary
        newId = self._database[self._collection].save(existing_dictionary)
        if not self.id:
            self.id = newId

    def delete(self):
        \"""
            Delete the object in the database
        \"""
        
        existing_dictionary = self._database[self._collection].remove( { "_id" : ObjectId(self.id) } )
        self = None

    def load(self, oid=None):
        \"""
            Load the object from the database
        \"""
        if not oid:
            oid = self.id
        if not oid:
            raise Exception("No ID specified")

        return self.load_by_query( { "_id" : ObjectId(oid) } )
        
    def load_by_query(self, query):
        \"""
            Load object from query specific query
        \"""
        dictionary = self._database[self._collection].find_one( query )
        if not dictionary:
            raise Exception("Not found")
        self.by_dictionary(dictionary)
        return self

    def find_objects(self, query, limit=100, page=0):
        \"""
            Find all the objects with a specific query
        \"""
        query = self._database[self._collection].find(query)
        query.limit(limit)
        if page > 0:
            query.skip(int(limit*page))

        objects = list()
        for data in query:
            new_object = self.__class__()
            new_object.database = self._database
            new_object.by_dictionary(data)
            objects.append(new_object)
        return objects
    
    def find_all(self, limit=100, page=0):
        \"""
            Find all the objects
        \"""
        return self.find_objects({}, limit=limit, page=page)

    def by_dictionary(self, dictionary, json=False):
        \"""
            This function loads the dictionary inside the object
        \"""
        self.id = dictionary['_id']
        if json:
            self.id = ObjectId(dictionary['_id'])
        
    def __dict__(self, json=False):
        \"""
            This function returns a dict of the Object.
        \"""
        output = dict()
        if self.id:
            output['_id'] = self.id
        if not json:
            output['_id'] = str(self.id)
        
        return output
        
    def __json__(self, json=False):
        \"""
            This function returns a json dict of the Object.
        \"""
        return json.dumps(self.__dict__(json=True))
""" )
    objectMaster_file.close()

    config_file = open(os.path.join(basepath,"settings.py"), "a")
    config_file.write("""#MongoDB Configuration
# for MyObject.connect(...) 

MONGO_HOST = "127.0.0.1"
MONGO_PORT = 27017
MONGO_DB = "%s" 

MONGO_NEEDS_AUTH = False
MONGO_USERNAME = "username"
MONGO_PASSWORD = "password"
    
""" % name)
    config_file.close()

    return
    
def install_examples(basepath, name):
    """
        Install MongoDB Module examples
    """
    
    example_file = open(os.path.join(basepath,"%s/objects/Example.py" % name), "w")
    example_file.write("""#!/usr/bin/env python
# -*- coding=utf-8 -*-

from pymongo.objectid import ObjectId
from %s.objects.Master import Master

class Example(Master):
    def __init__(self, database):
        super( Master, self ).__init__()
        self.id = ObjectId()
        
        self.dictionary = {"key":"value"}
        self.koalalorenzo = "is a great programmer"
        
        self._database = database
        self._collection = "Example"
        
    def by_dictionary(self, dictionary, json=False):
        \"""
            This function loads the dictionary inside the object
        \"""
        self.id = dictionary['_id']
        self.dictionary = dictionary['dictionary']
        self.koalalorenzo = dictionary['koalalorenzo']
        if json:
            self.id = ObjectId(dictionary['_id'])
        
    def __dict__(self, json=False):
        \"""
            This function returns a dict of the Object.
        \"""
        output = dict()
        output['_id'] = self.id
        output['dictionary'] = self.dictionary
        output['koalalorenzo'] = self.koalalorenzo
        
        if not json:
            output['_id'] = str(self.id)
        
        return output

""" % name)
    example_file.close()

    return


#!/usr/bin/python
# -*- coding=utf-8 -*-

import os
import urllib2
import zipfile

__help__ = """This module will install jquery."""


requirements = [ ]

directories = [
    "[base]",
    "[base]/[name]",
    "[base]/[name]/static",
]

files = [ ]

def install(basepath, name):
    """
        Download Install jquery files 
    """
    # http://twitter.github.io/bootstrap/assets/bootstrap.zip
    
    static_files_path = os.path.join(basepath, name, "static/")
    jquery_file_path = os.path.join(static_files_path,"jquery.min.js")

    remote_file = urllib2.urlopen('http://code.jquery.com/jquery-latest.min.js').read()
    localfile = open(jquery_file_path, 'w')
    localfile.write(remote_file)
    localfile.close()
    
    return
    
def install_examples(basepath, name):
    """
        Install jquery examples. 
    """
    #TODO

    return


#!/usr/bin/python
# -*- coding=utf-8 -*-

import os
import string
import random

__help__ = """ Flask is a microframework for Python based on Werkzeug, Jinja 2 and good intentions. """


requirements = [
    "flask"
]

directories = [
    "[base]/[name]",
    "[base]/[name]/templates",
    "[base]/[name]/static",
    "[base]/[name]/views",
]

files = [
    "[base]/settings.py",
    "[base]/server.py",
    "[base]/[name]/__init__.py",
    "[base]/[name]/constants.py",
    "[base]/[name]/decorators.py",
    "[base]/[name]/views/__init__.py",
]

def install(basepath, name):
    """
        Install Flask Module
    """
    
    init_file = open(os.path.join(basepath,"%s/__init__.py" % name), "w")
    init_file.write("""#!/usr/bin/python
# -*- coding=utf-8 -*-

\"""%s: Project Based on Steroids\"""

__version__ = "0.1"
__author__ = "Your Name ( http://projects.setale.me/Steroids )"
__author_email__ = "your_super_email_addr@domain.com"
__license__ = ""
__copyright__ = "Copyright (c) 2013, 2014 Somebody"

from flask import Flask
from flask import url_for
from flask import redirect

from settings import *

app = Flask(__name__)
app.secret_key = FLASK_SECRET_KEY

# Static Files
@app.route('/static/<path:afilepath>')
def serve_static(afilepath):
    return redirect(url_for('static', filename=afilepath))

# Import Views here:
# Ex: import %s.views.ViewName
""" % (name, name))

    random_value = ''.join(random.choice(string.ascii_uppercase + string.digits) for x in range(32))
    config_file = open(os.path.join(basepath,"settings.py"), "a")
    config_file.write("""# -*- coding=utf-8 -*-
    
# Flask Config
FLASK_SECRET_KEY = "%s"
SERVER_PORT = 8080
SERVER_HOST = "0.0.0.0"
FLASK_DEBUG = True
""" % random_value)
    
    server_file = open(os.path.join(basepath,"server.py"), "w")
    server_file.write("""
from %s import app
from settings import FLASK_DEBUG, SERVER_PORT, SERVER_HOST

app.debug = FLASK_DEBUG
if __name__ == "__main__":
    app.run(host=SERVER_HOST, port=SERVER_PORT)
""" % name)
    
    
    return
    
def install_examples(basepath, name):
    """
        Install Flask Module
    """
    
    init_file = open(os.path.join(basepath,"%s/__init__.py" % name), "a")
    init_file.write("\nimport %s.views.example\n" % name)
    init_file.close()
    
    example_file = open(os.path.join(basepath,"%s/views/example.py" % name), "w")
    example_file.write("""#!/usr/bin/python
# -*- coding=utf-8 -*-
from %s import app
from %s.decorators import *
from %s.constants import *

from flask import render_template
from flask import url_for
from flask import session
from flask import abort
from flask import redirect
from flask import flash

@app.route("/")
def homeExample_homepage():
    return render_template("homeExample/homepage.html")

""" % (name, name, name))
    example_file.close()
    
    example_template_layout_file = open(os.path.join(basepath,"%s/templates/layout.html" % name), "w")
    example_template_layout_file.write("""<html><head><title>Steroids</title></head><body>
<hr>
{%% block container %%}
{%% endblock %%}
<hr>
%s is powered by <a href="http://projects.setale.me/Steroids">Steroids</a>
</body></html>""" % name)
    example_template_layout_file.close()   
    
    if not os.path.exists(os.path.join(basepath,"%s/templates/homeExample" % name)):
        os.mkdir(os.path.join(basepath,"%s/templates/homeExample" % name))
    
    example_template_file = open(os.path.join(basepath,"%s/templates/homeExample/homepage.html" % name), "w")
    example_template_file.write("""{% extends "layout.html" %}

{% block container %}
<h1>Hello World!</h1>
This is an example!
{% endblock %}

""")
    example_template_file.close()   
    
    return


import os


def create_directories(basepath, name, directiores):
    """
        Create the directories
    """
    for path in directiores:
        path = path.replace("[base]", basepath)
        path = path.replace("[name]", name)
        
        if not os.path.exists(path):
            os.mkdir(path)

def touch_files(basepath, name, files):
    """
        Touch the files
    """
    for path in files:
        path = path.replace("[base]", basepath)
        path = path.replace("[name]", name)
        
        if not os.path.exists(path):
            open(path, 'w').close()
            
def install_module(module, basepath, name, examples=False):
    create_directories(basepath, name, module.directories)
    touch_files(basepath, name, module.files)
    module.install(basepath, name)
    if examples:
        module.install_examples(basepath, name)
    


"""Steroids is a set of tools to help python developers to build cool stuff reducing efforts and time."""

__version__ = "0.12"
__author__ = "Lorenzo Setale ( http://who.is.lorenzo.setale.me/? )"
__author_email__ = "koalalorenzo@gmail.com"
__license__ = "Creative Commons Attribution-ShareAlike 3.0 Unported License http://creativecommons.org/licenses/by-nd/3.0/ "
__copyright__ = "Copyright (c) 2013, 2014 Lorenzo Setale"


from . import apscheduler
from . import bootstrap
from . import flask
from . import flasktornado
from . import mongodb
from . import honcho
from . import rethinkdb
from . import topcoat
from . import gae
from . import gunicorn
from . import jquery



#!/usr/bin/python
# -*- coding=utf-8 -*-

import os

__help__ = """RethinkDB: An open-source distributed database built with love.

This module provide integration with rethinkdb to save objects inside a RethinkDB instance."""


requirements = [
    "rethinkdb"
]

directories = [
    "[base]/[name]",
    "[base]/[name]/objects",
]

files = [
    "[base]/settings.py",
    "[base]/[name]/__init__.py",
    "[base]/[name]/objects/__init__.py",
    "[base]/[name]/objects/Master.py",
]

def install(basepath, name):
    """
        Install RethinkDB Module
    """
    
    objectMaster_file = open(os.path.join(basepath,"%s/objects/Master.py" % name), "w")
    objectMaster_file.write("""#!/usr/bin/env python
# -*- coding=utf-8 -*-
import rethinkdb as r
import json


class Master(object):
    def __init__(self):
        self.id = None

        self._connection = None
        self._database = None
        self._collection = str()

    def connect(self, host, port, dbname, collection=None, username=None, password=None):
        \"""
            This function will connect the object to the database. 
        \"""
        return 

    def save(self):
        \"""
            Save the object in the database and overwrite if it already exists.
        \"""
        
        dictionary = self.__dict__()
        
        return

    def delete(self):
        \"""
            Delete the object in the database
        \"""
        
        return

    def load(self, oid=None):
        \"""
            Load the object from the database
        \"""
        return self

        
    def load_by_query(self, query):
        \"""
            Load object from query specific query
        \"""

        return self

    def find_objects(self, query, limit=100, page=0):
        \"""
            Find all the objects with a specific query
        \"""
        
        return list()
    
    def find_all(self, limit=100, page=0):
        \"""
            Find all the objects
        \"""
        return list()

    def by_dictionary(self, dictionary, json=False):
        \"""
            This function loads the dictionary inside the object
        \"""
        return
        
    def __dict__(self, json=False):
        \"""
            This function returns a dict of the Object.
        \"""
        output = dict()
        return output
        
    def __json__(self, json=False):
        \"""
            This function returns a json dict of the Object.
        \"""
        return json.dumps(self.__dict__(json=True))
""" % name )
    objectMaster_file.close()

    config_file = open(os.path.join(basepath,"settings.py"), "a")
    config_file.write("""#RethinkDB Configuration
# for MyObject.connect(...) 
RETHINKDB_HOST = "127.0.0.1"
RETHINKDB_PORT = 27017
RETHINKDB_DB = "%s" 

RETHINKDB_NEEDS_AUTH = False
RETHINKDB_USERNAME = "username"
RETHINKDB_PASSWORD = "password"
    
""" % name)
    config_file.close()

    return
    
def install_examples(basepath, name):
    """
        Install RethinkDB Module examples
    """
    
    example_file = open(os.path.join(basepath,"%s/objects/Example.py" % name), "w")
    example_file.write("""#!/usr/bin/env python
# -*- coding=utf-8 -*-

from %s.objects.Master import Master

class Example(Master):
    def __init__(self, database):
        super( Master, self ).__init__()
        self.id = ""
        
        self.dictionary = {"key":"value"}
        self.koalalorenzo = "is a great programmer"
        
        self._database = database
        self._collection = "Example"
        
    def by_dictionary(self, dictionary, json=False):
        \"""
            This function loads the dictionary inside the object
        \"""
        self.id = dictionary['id']
        self.dictionary = dictionary['dictionary']
        self.koalalorenzo = dictionary['koalalorenzo']
        if json:
            self.id = dictionary['id']
        
    def __dict__(self, json=False):
        \"""
            This function returns a dict of the Object.
        \"""
        output = dict()
        output['id'] = self.id
        output['dictionary'] = self.dictionary
        output['koalalorenzo'] = self.koalalorenzo
        
        if not json:
            output['id'] = str(self.id)
        
        return output

""" % name)
    example_file.close()

    return


#!/usr/bin/env python
import os
from setuptools import setup

setup(name='steroids',
      version='0.12',
      description='Steroids is a set of tools to help python developers to build cool stuff reducing efforts and time.',
      author='Lorenzo Setale ( http://who.is.lorenzo.setale.me/? )',
      author_email='koalalorenzo@gmail.com',
      url='https://github.com/koalalorenzo/Steroids',
      packages=['steroids', 'steroids.modules'],
      scripts=['scripts/steroids']
     )



#!/usr/bin/python
# -*- coding=utf-8 -*-

import os
import stat   

__help__ = """Gunicorn 'Green Unicorn' is a Python WSGI HTTP Server for UNIX.
"""


requirements = [
    "gunicorn"
]

directories = [ ]

files = [
    "[base]/start.sh"
]

def install(basepath, name):
    """
        Install gunicorn module
    """

    start_file_path = os.path.join(basepath,"start.sh")
    start_file = open(start_file_path, "a")
    start_file.write("#!/bin/bash \n")
    start_file.write("gunicorn server:app \n")
    start_file.close()

    old_perms = os.stat(start_file_path)
    os.chmod(start_file_path, old_perms.st_mode | stat.S_IEXEC)

    return
    
def install_examples(basepath, name):
    """
        Install gunicorn module examples
    """
    start_file = open(os.path.join(basepath,"start.sh"), "a")
    start_file.write("##Other commands examples: \n")
    start_file.write("# gunicorn server:app -k gevent # non blocking server \n")
    start_file.write("# gunicorn server:app -k gevent -b 0.0.0.0:80 # on port 80 \n")
    start_file.close()

    if os.path.exists(os.path.join(basepath,"Procfile")):
        proc_file = open(os.path.join(basepath,"Procfile"), "a")
        proc_file.write("# Gunicorn commands examples:\n")
        proc_file.write("# web: gunicorn server:app # gunicorn server \n")
        proc_file.write("# web: gunicorn server:app -k gevent # non blocking server \n")
        proc_file.write("# web: gunicorn server:app -k gevent -b 0.0.0.0:80 # on port 80 \n")
        proc_file.close()

    return


import os

__help__ = """This module will improve flask performance using Tornado non blocking web server."""


requirements = [
    "tornado"
]

directories = [
    "[base]",
    ]

files = [
    "[base]/flasktornado.py",
    ]

def install(basepath, name):
    """
        Install Flask-Tornado Module
    """
    
    tornado_file = open(os.path.join(basepath,"flasktornado.py"), "w")
    tornado_file.write("from tornado.wsgi import WSGIContainer\n")
    tornado_file.write("from tornado.httpserver import HTTPServer\n")
    tornado_file.write("from tornado.ioloop import IOLoop\n")
    tornado_file.write("from settings import SERVER_PORT\n")
    tornado_file.write("from %s import app as application\n" % name)
    tornado_file.write("\n")
    tornado_file.write("http_server = HTTPServer(WSGIContainer(application))\n")
    tornado_file.write("http_server.listen(SERVER_PORT)\n")
    tornado_file.write("IOLoop.instance().start()\n")
    tornado_file.close()
    return
    
def install_examples(basepath, name):
    """
        Install Flask-Tornado Module with example files
    """
    return


#!/usr/bin/python
# -*- coding=utf-8 -*-

import os
import urllib2
import zipfile
import shutil

__help__ = """This module will install topcoat css style. Version: 0.3.0"""

requirements = [ ]

directories = [
    "[base]",
    "[base]/[name]",
    "[base]/[name]/static",
    "[base]/[name]/static/topcoat",
    "[base]/[name]/templates",
    "[base]/[name]/views",
]

files = [ 
    "[base]/[name]/templates/topcoat.html",
    "[base]/[name]/views/__init__.py",
]

def install(basepath, name):
    """
        Download Install Topcoat 0.3.0 files 
    """
    # https://github.com/topcoat/topcoat/archive/0.3.0.zip
    
    static_files_path = os.path.join(basepath, name, "static/")
    final_files_path = os.path.join(basepath, name, "static/topcoat")
    temporary_files_path = os.path.join(basepath, name, "static/topcoat/temporary")
    topcoat_file_path = os.path.join(static_files_path, "topcoat.zip")
    
    os.makedirs(temporary_files_path)
    
    remote_file = urllib2.urlopen('http://github.com/topcoat/topcoat/archive/0.3.0.zip').read()
    localfile = open(topcoat_file_path, 'w')
    localfile.write(remote_file)
    localfile.close()

    current_dir = os.getcwd()
    topoact_zip = zipfile.ZipFile(topcoat_file_path)
    os.chdir(temporary_files_path)
    for f in topoact_zip.namelist():
        if f.endswith('/'):
            new_directory = os.path.join(temporary_files_path,f)
            if not os.path.exists(new_directory):
                os.makedirs(new_directory)
        else:
            topoact_zip.extract(f)
    os.chdir(current_dir)
    os.remove(topcoat_file_path)
    
    release_files_path = os.path.join(temporary_files_path,"topcoat-0.3.0/release")
    shutil.move(os.path.join(release_files_path,"css"), final_files_path)
    shutil.move(os.path.join(release_files_path,"font"), final_files_path)
    shutil.move(os.path.join(release_files_path,"img"), final_files_path)
    shutil.rmtree(temporary_files_path)

    topcoat_layout_file = open(os.path.join(basepath,name,"templates/topcoat.html"), "w")
    topcoat_layout_file.write("""<html>
    <head>
        <title>%s {%% block title %%}{%% endblock %%}</title>

        <meta charset="utf-8">
        <link rel="stylesheet" type="text/css" href="/static/topcoat/css/topcoat-mobile-light.min.css">
        
        <!-- Le HTML5 shim, for IE6-8 support of HTML5 elements -->
        <!--[if lt IE 9]>
          <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
        <![endif]-->
        {%% block head %%}{%% endblock %%}
    </head>
    <body>
        {%% block header %%}{%% endblock %%}
        {%% block container %%}{%% endblock %%}
        %s is powered by <a href="http://projects.setale.me/Steroids">Steroids</a>
        {%% block footer %%}{%% endblock %%}
    </body>    
</html>""" % (name, name))
    topcoat_layout_file.close()
    
    return
    
def install_examples(basepath, name):
    """
        Install Topcoat 0.3.0 Templates files. ( examples )
    """
    example_directory = os.path.join(basepath,name,"templates/examples")
    if not os.path.exists(example_directory):
        os.mkdir(example_directory)

    topcoat_examples_directory = os.path.join(example_directory, "topcoat")
    if not os.path.exists(topcoat_examples_directory):
        os.mkdir(topcoat_examples_directory)

    topcoat_example_template_file = open(os.path.join(topcoat_examples_directory, "homepage.html"), "w")
    topcoat_example_template_file.write("""{% extends "topcoat.html" %}

{% block container %}
<h1>Hello World!</h1>
<div>
    This is an example using Topcoat!
</div>
{% endblock %}
""")
    topcoat_example_template_file.close()
    
    init_file = open(os.path.join(basepath, name, "__init__.py"), "a")
    init_file.write("\nimport %s.views.topcoatExample\n" % name)
    init_file.close()
    
    example_view_file = open(os.path.join(basepath, name, "views/topcoatExample.py"), "w")
    example_view_file.write("""#!/usr/bin/python
# -*- coding=utf-8 -*-
from %s import app
from %s.decorators import *
from %s.constants import *

from flask import render_template
from flask import url_for
from flask import session
from flask import abort
from flask import redirect
from flask import flash

@app.route("/topcoat")
def topcoatExample_homepage():
    return render_template("examples/topcoat/homepage.html")

""" % (name, name, name))
    example_view_file.close()

    return


import os

__help__ = """
"""

requirements = [
    "apscheduler"
]

directories = [
    "[base]",
    "[base]/[name]",
    ]

files = [
    "[base]/clock.py",
    "[base]/[name]/clock.py",
    ]

def install(basepath, name):
    """
        Install apscheduler Module
    """
    
    clock_file = open(os.path.join(basepath,"clock.py"), "w")
    clock_file.write("from %s.clock import sched\n" % name)    
    clock_file.write("""
sched.start()
while True:
    if not sched.running:
        break
    sleep(30)
        
""")
    clock_file.close()

    nameclock_file = open(os.path.join(basepath,"%s/clock.py" % name), "w")    
    nameclock_file.write("import sys\n")
    nameclock_file.write("from apscheduler.scheduler import Scheduler\n")
    nameclock_file.write("\n")
    nameclock_file.write("sched = Scheduler()\n")
    nameclock_file.close()
    return
    
def install_examples(basepath, name):
    """
        Install Tornado Module with example files
    """
    nameclock_file = open(os.path.join(basepath,"%s/clock.py" % name), "a")    
    nameclock_file.write("""
# Examples APScheduler

@sched.interval_schedule(minutes=5)
def every_five_minutes():
    print "5 minutes"

@sched.cron_schedule(day='last sun')
def some_decorated_task():
    print "I am printed at 00:00:00 on the last Sunday of every month!"

# End Examples
""")
    nameclock_file.close()
    return